==> atlantic-2.0.0-sources.jar: org/mule/commons/atlantic/lambda/consumer/HeptaConsumer.java <==
package org.mule.commons.atlantic.lambda.consumer;

import org.mule.commons.atlantic.lambda.function.HeptaFunction;

/**
 * Represents an operation that accepts seven input arguments and returns no result.  This is the seven-arity
 * specialization of {@link Consumer}.
 * Unlike most other functional interfaces, {@code HeptaConsumer} is expected to operate via side-effects.
 *
 * This is a functional interface whose functional method is {@link #accept(Object, Object, Object, Object, Object, Object, Object)}.
 *
 * @param <A> The type of the first argument to the operation.
 * @param <B> The type of the second argument to the operation.
 * @param <C> The type of the third argument to the operation.
 * @param <D> The type of the fourth argument to the operation.
 * @param <E> The type of the fifth argument to the operation.
 * @param <F> The type of the sixth argument to the operation.
 * @param <G> The type of the seventh argument to the operation.
 */
@FunctionalInterface
public interface HeptaConsumer<A, B, C, D, E, F, G> extends AtlanticConsumer<HeptaFunction<A, B, C, D, E, F, G, Void>> {

    /**
     * Performs this operation on the given arguments.
     *
     * @param a The first input argument.
     * @param b The second input argument.
     * @param c The third input argument.
     * @param d The fourth input argument.
     * @param e The fifth input argument.
     * @param f The sixth input argument.
     * @param g The seventh input argument.
     * @throws Throwable Any exception that the operation will throw.
     */
    void accept(A a, B b, C c, D d, E e, F f, G g) throws Throwable;

    @Override
    default HeptaFunction<A, B, C, D, E, F, G, Void> toFunction() {
        return (a, b, c, d, e, f, g) -> {
            accept(a, b, c, d, e, f, g);
            return null;
        };
    }
}

==> atlantic-3.1.0-sources.jar: org/mule/commons/atlantic/lambda/consumer/HeptaConsumer.java <==
package org.mule.commons.atlantic.lambda.consumer;

import org.mule.commons.atlantic.lambda.function.HeptaFunction;
import org.mule.commons.atlantic.lambda.supplier.Supplier;

/**
 * Represents an operation that accepts seven input arguments and returns no result.  This is the seven-arity
 * specialization of {@link Consumer}.
 * Unlike most other functional interfaces, {@code HeptaConsumer} is expected to operate via side-effects.
 *
 * This is a functional interface whose functional method is {@link #accept(Object, Object, Object, Object, Object, Object, Object)}.
 *
 * @param <A> The type of the first argument to the operation.
 * @param <B> The type of the second argument to the operation.
 * @param <C> The type of the third argument to the operation.
 * @param <D> The type of the fourth argument to the operation.
 * @param <E> The type of the fifth argument to the operation.
 * @param <F> The type of the sixth argument to the operation.
 * @param <G> The type of the seventh argument to the operation.
 */
@FunctionalInterface
public interface HeptaConsumer<A, B, C, D, E, F, G> extends AtlanticConsumer<A, HexaConsumer<B, C, D, E, F, G>, HeptaFunction<A, B, C, D, E, F, G, Void>> {

    @Override
    default HexaConsumer<B, C, D, E, F, G> downgrade(Supplier<A> supplier) {
        return (b, c, d, e, f, g) -> accept(supplier.get(), b, c, d, e, f, g);
    }

    /**
     * Performs this operation on the given arguments.
     *
     * @param a The first input argument.
     * @param b The second input argument.
     * @param c The third input argument.
     * @param d The fourth input argument.
     * @param e The fifth input argument.
     * @param f The sixth input argument.
     * @param g The seventh input argument.
     * @throws Throwable Any exception that the operation will throw.
     */
    void accept(A a, B b, C c, D d, E e, F f, G g) throws Throwable;

    @Override
    default HeptaFunction<A, B, C, D, E, F, G, Void> toFunction() {
        return (a, b, c, d, e, f, g) -> {
            accept(a, b, c, d, e, f, g);
            return null;
        };
    }
}
